@@ -340,9 +340,9 @@ class Composer:
             sender=sender, data=data
         )
 
-    def MsgRewardsOptOut(self, sender: str, dmm_account: str):
+    def MsgRewardsOptOut(self, sender: str):
         return injective_exchange_tx_pb.MsgRewardsOptOut(
-            sender=sender, dmm_account=dmm_account
+            sender=sender
         )
 
     def MsgCreateDerivativeLimitOrder(
