@@ -66,6 +66,7 @@ class Network:
         tm_websocket_endpoint: str,
         grpc_endpoint: str ,
         grpc_exchange_endpoint: str ,
+        grpc_explorer_endpoint: str ,
         chain_id: str ,
         fee_denom: str ,
         env: str
@@ -74,6 +75,7 @@ class Network:
         self.tm_websocket_endpoint = tm_websocket_endpoint
         self.grpc_endpoint = grpc_endpoint
         self.grpc_exchange_endpoint = grpc_exchange_endpoint
+        self.grpc_explorer_endpoint = grpc_explorer_endpoint
         self.chain_id = chain_id
         self.fee_denom = fee_denom
         self.env = env
@@ -85,6 +87,7 @@ class Network:
             tm_websocket_endpoint='wss://devnet.tm.injective.dev/websocket',
             grpc_endpoint='devnet.injective.dev:9900',
             grpc_exchange_endpoint='devnet.injective.dev:9910',
+            grpc_explorer_endpoint='devnet.injective.dev:9911',
             chain_id='injective-777',
             fee_denom='inj',
             env='devnet'
@@ -97,6 +100,7 @@ class Network:
             tm_websocket_endpoint='wss://k8s.testnet.tm.injective.network/websocket',
             grpc_endpoint='k8s.testnet.chain.grpc.injective.network:443',
             grpc_exchange_endpoint='k8s.testnet.exchange.grpc.injective.network:443',
+            grpc_explorer_endpoint='k8s.testnet.explorer.grpc.injective.network:443',
             chain_id='injective-888',
             fee_denom='inj',
             env='testnet'
@@ -120,22 +124,26 @@ class Network:
             tm_websocket_endpoint='wss://k8s.mainnet.tm.injective.network:443/websocket'
             grpc_endpoint='k8s.mainnet.chain.grpc.injective.network:443'
             grpc_exchange_endpoint='k8s.mainnet.exchange.grpc.injective.network:443'
+            grpc_explorer_endpoint='k8s.mainnet.explorer.grpc.injective.network:443'
         elif node == 'lb':
-          lcd_endpoint = 'https://k8s.global.mainnet.lcd.injective.network:443'
-          tm_websocket_endpoint = 'wss://k8s.global.mainnet.tm.injective.network:443/websocket'
-          grpc_endpoint = 'k8s.global.mainnet.chain.grpc.injective.network:443'
-          grpc_exchange_endpoint = 'k8s.global.mainnet.exchange.grpc.injective.network:443'
+            lcd_endpoint = 'https://k8s.global.mainnet.lcd.injective.network:443'
+            tm_websocket_endpoint = 'wss://k8s.global.mainnet.tm.injective.network:443/websocket'
+            grpc_endpoint = 'k8s.global.mainnet.chain.grpc.injective.network:443'
+            grpc_exchange_endpoint = 'k8s.global.mainnet.exchange.grpc.injective.network:443'
+            grpc_explorer_endpoint = 'k8s.global.mainnet.explorer.grpc.injective.network:443'
         else:
             lcd_endpoint='https://lcd.injective.network'
             tm_websocket_endpoint=f'ws://{node}.injective.network:26657/websocket'
             grpc_endpoint=f'{node}.injective.network:9900'
             grpc_exchange_endpoint=f'{node}.injective.network:9910'
+            grpc_explorer_endpoint=f'{node}.injective.network:9911'
 
         return cls(
             lcd_endpoint=lcd_endpoint,
             tm_websocket_endpoint=tm_websocket_endpoint,
             grpc_endpoint=grpc_endpoint,
             grpc_exchange_endpoint=grpc_exchange_endpoint,
+            grpc_explorer_endpoint=grpc_explorer_endpoint,
             chain_id='injective-1',
             fee_denom='inj',
             env='mainnet'
@@ -148,18 +156,20 @@ class Network:
             tm_websocket_endpoint='ws://localost:26657/websocket',
             grpc_endpoint='localhost:9900',
             grpc_exchange_endpoint='localhost:9910',
+            grpc_explorer_endpoint='localhost:9911',
             chain_id='injective-1',
             fee_denom='inj',
             env='local'
         )
 
     @classmethod
-    def custom(cls, lcd_endpoint, tm_websocket_endpoint, grpc_endpoint, grpc_exchange_endpoint, chain_id, env):
+    def custom(cls, lcd_endpoint, tm_websocket_endpoint, grpc_endpoint, grpc_exchange_endpoint, grpc_explorer_endpoint, chain_id, env):
         return cls(
             lcd_endpoint=lcd_endpoint,
             tm_websocket_endpoint=tm_websocket_endpoint,
             grpc_endpoint=grpc_endpoint,
             grpc_exchange_endpoint=grpc_exchange_endpoint,
+            grpc_explorer_endpoint=grpc_explorer_endpoint,
             chain_id=chain_id,
             fee_denom='inj',
             env=env
